@@ -113,8 +113,8 @@ def multifunc(function,allvars,procaxis,vardims):
     # amount of non-processed input dimensions
     nonprocdim = len(where(array(trnsprocaxis) == False)[0])
     # amount of extra dimensions introduced by the function
-    # extradims = len(shape(dataouttrns)) - len(trnsprocaxis)
-    print('extradims',extradims)
+    extradims = len(shape(dataouttrns)) - len(trnsprocaxis)
+    # print('extradims',extradims)
     trnsoutaxis = list(trnsprocaxis)
 
 
